##  Inventory AI Prompts
Inventory AI prompts combines the information in your inventory with the power of generative AI to make enterprise architecture information more accessible and actionable. It provides a natural language interface for interacting with your enterprise architecture repository, allowing you to ask questions, query data, and receive insights using everyday language. You can use predefined requests or your own prompts to get assistance in various tasks.
With the inventory AI prompts, you can:
  * Generate descriptions and get better context.
  * Request recommendations for optimizing enterprise architecture based on best practices, industry standards, and organizational goals.
  * Query for suggestions on changes to application portfolios, infrastructure configurations, and IT governance processes.
  * Obtain details about specific data objects, such as their attributes, dependencies, and usage, and get assistance in data object-related operations through REST API examples.
  * Obtain quick insights regarding potential risks, relevant regulations, and standards.
